@@ -108,9 +108,9 @@ def command(
             from decorators and inferred from the method signature.
         command_type: The command type. Valid options are Command.COMMAND_TYPES.
         output_type: The output type. Valid options are Command.OUTPUT_TYPES.
-        schema: A custom schema definition.
-        form: A custom form definition.
-        template: A custom template definition.
+        schema: Deprecated and will be removed in future release. Custom schema definition.
+        form: Deprecated and will be removed in future release. Custom form definition.
+        template: Deprecated and will be removed in future release. Custom template definition.
         icon_name: The icon name. Should be either a FontAwesome or a Glyphicon name.
         hidden: Flag controlling whether the command is visible on the user interface.
         metadata: Free-form dictionary
@@ -118,7 +118,24 @@ def command(
     Returns:
         The decorated function
     """
+
     if _wrapped is None:
+
+        if form is not None:
+            _deprecate(
+                "Use of form with @command is now deprecated and will eventually be removed"
+            )
+
+        if schema is not None:
+            _deprecate(
+                "Use of schema with @command is now deprecated and will eventually be removed"
+            )
+
+        if template is not None:
+            _deprecate(
+                "Use of template with @command is now deprecated and will eventually be removed"
+            )
+
         return functools.partial(
             command,
             description=description,
