@@ -85,8 +85,13 @@ class Events(Enum):
     JOB_EXECUTED = 43
     USER_UPDATED = 44
     USERS_IMPORTED = 45
+    ROLE_UPDATED = 46
+    ROLES_IMPORTED = 47
+    COMMAND_PUBLISHING_BLOCKLIST_SYNC = 48
+    COMMAND_PUBLISHING_BLOCKLIST_REMOVE = 49
+    COMMAND_PUBLISHING_BLOCKLIST_UPDATE = 50
 
-    # Next: 46
+    # Next: 51
 
 
 class BaseModel(object):
