@@ -2,9 +2,9 @@
 """This module currently exists to maintain backwards compatibility."""
 import warnings
 
-from brewtils.pika import PIKA_ONE, PikaClient
+from brewtils.pika import PikaClient
 
-__all__ = ["PIKA_ONE", "PikaClient"]
+__all__ = ["PikaClient"]
 
 warnings.warn(
     "This module has been migrated to brewtils.pika and will be removed in a future "
